@@ -6,10 +6,7 @@ import (
 
 	"github.com/charmbracelet/gum/internal/exit"
 
-	"github.com/alecthomas/kong"
 	tea "github.com/charmbracelet/bubbletea"
-
-	"github.com/charmbracelet/gum/style"
 )
 
 // Run provides a shell script interface for prompting a user to confirm an
@@ -42,9 +39,3 @@ func (o Options) Run() error {
 
 	return nil
 }
-
-// BeforeReset hook. Used to unclutter style flags.
-func (o Options) BeforeReset(ctx *kong.Context) error {
-	style.HideFlags(ctx)
-	return nil
-}
